==> kxmleditor-0.7.2.tar.gz: kxmleditor-0.7.2/part/kxmleditorfactory.h <==
/***************************************************************************
                          kxmleditorfactory.h  -  description
                             -------------------
    begin                : Wed Sep 19 2001
    copyright            : (C) 2001 by The KXMLEditor Team
    email                : OleBowle@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KXMLEDITORFACTORY_H
#define KXMLEDITORFACTORY_H

#include <kparts/factory.h>

class KInstance;

class KXMLEditorFactory : public KParts::Factory
{
		Q_OBJECT

	public:
		KXMLEditorFactory( QObject * pParent = 0, const char * pszName = 0 );
		virtual ~KXMLEditorFactory();

		virtual KParts::Part * createPartObject( QWidget * pParentWidget = 0, const char * pszWidgetName = 0, QObject * pParent = 0, const char * pszName = 0, const char * pszClassName = "KParts::Part", const QStringList & args = QStringList() );

		static KInstance * instance();

	private:
		static KInstance * s_instance;
};

#endif

==> kxmleditor_1.0.0.orig.tar.gz: kxmleditor-1.0.0/part/kxmleditorfactory.h <==
/***************************************************************************
                          kxmleditorfactory.h  -  description
                             -------------------
    begin                : Wed Sep 19 2001
    copyright            : (C) 2001, 2002, 2003 by The KXMLEditor Team
    email                : OleBowle@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KXMLEDITORFACTORY_H
#define KXMLEDITORFACTORY_H

#include <kparts/factory.h>

class KInstance;
class KXEConfiguration;

class KXMLEditorFactory : public KParts::Factory
{
		Q_OBJECT

	public:
		KXMLEditorFactory( QObject * pParent = 0, const char * pszName = 0 );
		virtual ~KXMLEditorFactory();

		virtual KParts::Part * createPartObject( QWidget * pParentWidget = 0, const char * pszWidgetName = 0, QObject * pParent = 0, const char * pszName = 0, const char * pszClassName = "KParts::Part", const QStringList & args = QStringList() );

		static KInstance * instance();
		static KXEConfiguration * configuration();

	private:
		static KInstance * s_instance;

		/** our configuration - the same for all parts */
		static KXEConfiguration * s_pKXEConfig;
};

#endif
